#
# spec file for package Lunchbox
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%define soname 3
Name:           Lunchbox
Version:        1.10.0
Release:        lp150.8.16
Summary:        C++ library for multi-threaded programming
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Url:            http://equalizergraphics.com/
Source0:        https://github.com/Eyescale/Lunchbox/archive/1.10.0.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_git20150515.tar.gz
# PATCH-FIX-UPSTREAM include.patch avvissu@yandex.ru -- Remove Buildyard project
Patch0:         Lunchbox-1.10.0_include.patch
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru -- Fix build error: need administrative privileges
Patch1:         CMake_doxygen.patch
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 4.4
BuildRequires:  graphviz
BuildRequires:  pkg-config
BuildRequires:  python-devel
##########Recommends##########
BuildRequires:  avahi
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(avahi-compat-libdns_sd)
%if 0%{?suse_version} > 1310
BuildRequires:  libjpeg8-devel
%endif

%description
Lunchbox is C++ library for multi-threaded programming, providing OS
abstraction, utility classes and high-performance primitives, such as
atomic variables, spin locks and lock-free containers.

%package -n     lib%{name}%{soname}
Summary:        C++ library for multi-threaded programming
License:        LGPL-2.1
Group:          System/Libraries

%description -n lib%{name}%{soname}
Lunchbox is C++ library for multi-threaded programming, providing OS
abstraction, utility classes and high-performance primitives, such as
atomic variables, spin locks and lock-free containers.

%package 		devel
Summary:        Development files for %{name}
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}-%{release}
Requires:       libjpeg8-devel
Requires:       libboost_filesystem-devel
Requires:       libboost_regex-devel
Requires:       libboost_serialization-devel
Requires:       libboost_system-devel
Requires:       libboost_thread-devel
Requires:       pkgconfig(avahi-client)
Requires:       pkgconfig(avahi-compat-libdns_sd)

%description 	devel
C++ library for multi-threaded programming.

This package contains header files and libraries needed to develop
application that use %{name}.

%package 		doc
Summary:        Documentation for libLunchbox
Group:          Documentation/HTML
BuildArch:      noarch

%description 	doc
C++ library for multi-threaded programming.

API Documentation for %{name}.

%prep
%setup -q -a1
mv CMake-common* CMake/common
%patch0 -p1
pushd CMake/common
%patch1 -p1
popd

%build
# Do not compile in DATE and TIME
grep -rl 'HTML_TIMESTAMP' . | \
	xargs --no-run-if-empty --verbose \
	sed -i '/^HTML_TIMESTAMP/s/YES/NO/'

# Build with boost >= 1.60.0
%if 0%{?suse_version} > 1320
sed -i '/\~Foo()/d' tests/refPtr.cpp
%endif

%cmake \
	-DCMAKE_BUILD_TYPE=Release \
	-DCMAKE_SKIP_RPATH:BOOL=OFF

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}{%{_datadir}/%{name}/doc,%{_docdir}/lib%{name}%{soname}}

# Boost don't support pkg-config!
# Build bino: W: Package 'Boost', required by 'Lunchbox', not found
sed -i '/Requires/s/Boost//' %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%fdupes -s %{buildroot}%{_docdir}

%check
# Only local test (used avahi)
#sed -i '/ctest/s|\(bin/ctest\)|\1 -V|' build/Makefile
#make test -C build

%post -n lib%{name}%{soname} -p /sbin/ldconfig

%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_docdir}/lib%{name}%{soname}
%{_libdir}/lib%{name}.so.*
%exclude %{_docdir}/lib%{name}%{soname}/API

%files devel
%defattr(-,root,root)
%{_includedir}/lunchbox
%{_libdir}/lib%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}

%files doc
%defattr(-,root,root)
%{_docdir}/lib%{name}%{soname}/API

%changelog
* Sat Feb  4 2017 avvissu@yandex.by
- Build without MPI
* Thu Sep  8 2016 avvissu@yandex.by
- Build with boost >= 1.60.0
* Sat May 16 2015 avvissu@yandex.ru
- Update to 1.10.0
- Add source package CMake-common (Common CMake modules)
- Drop old patches:
  * build_with_boost-1.56.patch
  * DoxygenRule.diff
- Add new patches:
  * Lunchbox-1.10.0_include.patch
  * CMake_doxygen.patch
- Add recommended packages to build with optional packages
- Use %%%%cmake macro instead of cmake
* Sat May  9 2015 avvissu@yandex.ru
- Drop date-and-time.diff ((use echo (command))
- Drop double-ended_queue.patch
- Use pkg-config files
- Spec file cleanup
* Tue Dec 30 2014 avvissu@yandex.ru
- Fix build with boost 1.56 (build_with_boost-1.56.patch)
- Spec file cleanup
* Fri Mar 14 2014 avvissu@yandex.ru
- [Fixed] RPMlint W: Your file uses  __DATE and __TIME__ this
  causes the package to rebuild when not needed (date-and-time.diff)
* Wed Dec 25 2013 avvissu@yandex.ru
- BuildRequires:  avahi-compat-mDNSResponder-devel hwloc-devel
* Fri Dec 20 2013 avvissu@yandex.ru
- Initial release 1.8.0
